@@ -1,6 +1,6 @@
 package Devel::PatchPerl;
 {
-  $Devel::PatchPerl::VERSION = '0.50';
+  $Devel::PatchPerl::VERSION = '0.52';
 }
 
 # ABSTRACT: Patch perl source a la Devel::PPPort's buildperl.pl
@@ -208,14 +208,21 @@ sub _determine_version {
   return unless -e $patchlevel_h;
   my $version;
   {
+    my %defines;
     open my $fh, '<', $patchlevel_h;
     my @vers;
     while (<$fh>) {
       chomp;
-      next unless /^#define PERL_[RVS]/;
-      push @vers, (split /\s+/)[2];
+      next unless /^#define/;
+      my ($foo,$bar) = ( split /\s+/ )[1,2];
+      $defines{$foo} = $bar;
+    }
+    if ( my @wotsits = grep { defined $defines{$_} } qw(PERL_REVISION PERL_VERSION PERL_API_SUBVERSION) ) {
+      $version = join '.', map { $defines{$_} } @wotsits;
+    }
+    else {
+      $version = sprintf '5.%03d_%02d', map { $defines{$_} } qw(PATCHLEVEL SUBVERSION);
     }
-    $version = join '.', @vers;
   }
   return $version;
 }
@@ -1722,7 +1729,7 @@ Devel::PatchPerl - Patch perl source a la Devel::PPPort's buildperl.pl
 
 =head1 VERSION
 
-version 0.50
+version 0.52
 
 =head1 SYNOPSIS
 
